==> tsc_blue_print-0.0.1.tar.gz: android/src/main/java/com/sosempresarial/tsc_blue_print/TscBluePrint.java <==
package com.sosempresarial.tsc_blue_print;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.example.tscdll.TSCActivity;
import com.example.tscdll.TscWifiActivity;

/** TscBluePrintPlugin */
public class TscBluePrint implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  TSCActivity TscDll = new TSCActivity();
  TscWifiActivity TscEthernetDll = new TscWifiActivity();

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "tsc_blue_print");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if(call.method.equals("ble_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      String tara = call.argument("tara");
      String peso = call.argument("tara");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("number");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");
      int num = call.argument("num");

      TscDll.openport(ipAddress);
      TscDll.setup(70, 110, 4, 4, 0, 0, 0);
      TscDll.clearbuffer();
      TscDll.sendcommand("SIZE 47.5 mm, 25 mm\n");
      TscDll.sendcommand("GAP 3 mm, 0 mm\n");
      TscDll.sendcommand("DIRECTION 0,0\n");
      TscDll.sendcommand("REFERENCE 0,0\n");
      TscDll.sendcommand("OFFSET 0 mm\n");
      TscDll.sendcommand("SET PEEL OFF\n");
      TscDll.sendcommand("SET CUTTER OFF\n");
      TscDll.sendcommand("SET CUTTER OFF\n");
      TscDll.sendcommand("SET PARTIAL_CUTTER OFF\n");

      if (num < 10) {
        TscDll.sendcommand("@1 = \"1\"\n");
      } else if (num < 100) {
        TscDll.sendcommand("@01 = \"1\"\n");
      }else {
        TscDll.sendcommand("@001 = \"1\"\n");
      }

      TscDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: 0.58\"\n");
      TscDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"249221706202211.81\"\n");
      //TscDll.barcode(354,39,140,"39",32,180,1,3,"249221706202211.81\n");
      TscDll.barcode(100, 100, "128", 100, 1, 0, 3, 3, "123456789");
      //TscDll.sendcommand("BARCODE 354,140,\"39\",32,0,180,1,3,\"249221706202211.81\"");
      TscDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: 11.81\"\n");
      TscDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: 17062022\"\n");
      TscDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. 11.23\"\n");
      TscDll.sendcommand("TEXT 54,184,\"0\",180,9,9,\"24922\"\n");
      TscDll.sendcommand("TEXT 354,181,\"0\",180,8,8,\"PEC. SAN FRANCISCO(MAIZALES)\n");

      TscDll.printlabel(1, 1);
      //TscDll.sendfile("zpl.txt");
      TscDll.closeport(5000);

    } else if (call.method.equals("wifi_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      String tara = call.argument("tara");
      String peso = call.argument("tara");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("number");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");
      int num = call.argument("num");

      TscEthernetDll.openport(ipAddress,9100);
      TscEthernetDll.setup(70, 110, 4, 4, 0, 0, 0);
      TscEthernetDll.clearbuffer();
      TscEthernetDll.sendcommand("SIZE 47.5 mm, 25 mm\n");
      TscEthernetDll.sendcommand("GAP 3 mm, 0 mm\n");
      TscEthernetDll.sendcommand("DIRECTION 0,0\n");
      TscEthernetDll.sendcommand("REFERENCE 0,0\n");
      TscEthernetDll.sendcommand("OFFSET 0 mm\n");
      TscEthernetDll.sendcommand("SET PEEL OFF\n");
      TscEthernetDll.sendcommand("SET CUTTER OFF\n");
      TscEthernetDll.sendcommand("SET CUTTER OFF\n");
      TscEthernetDll.sendcommand("SET PARTIAL_CUTTER OFF\n");

      if (num < 10) {
        TscEthernetDll.sendcommand("@1 = \"1\"\n");
      } else if (num < 100) {
        TscEthernetDll.sendcommand("@01 = \"1\"\n");
      }else {
        TscEthernetDll.sendcommand("@001 = \"1\"\n");
      }

      TscEthernetDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: 0.58\"\n");
      TscEthernetDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"249221706202211.81\"\n");
      //TscEthernetDll.barcode(354,39,140,"39",32,180,1,3,"249221706202211.81\n");
      TscEthernetDll.barcode(100, 100, "128", 100, 1, 0, 3, 3, "123456789");
      //TscDll.sendcommand("BARCODE 354,140,\"39\",32,0,180,1,3,\"249221706202211.81\"");
      TscEthernetDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: 11.81\"\n");
      TscEthernetDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: 17062022\"\n");
      TscEthernetDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. 11.23\"\n");
      TscEthernetDll.sendcommand("TEXT 54,184,\"0\",180,9,9,\"24922\"\n");
      TscEthernetDll.sendcommand("TEXT 354,181,\"0\",180,8,8,\"PEC. SAN FRANCISCO(MAIZALES)\n");

      TscEthernetDll.printlabel(1, 1);
      //TscDll.sendfile("zpl.txt");
      TscEthernetDll.closeport(5000);

    } else {
      result.notImplemented();
    }

  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}

==> tsc_blue_print-0.0.2.tar.gz: android/src/main/java/com/sosempresarial/tsc_blue_print/TscBluePrint.java <==
package com.sosempresarial.tsc_blue_print;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.example.tscdll.TSCActivity;
import com.example.tscdll.TscWifiActivity;

/** TscBluePrintPlugin */
public class TscBluePrint implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  TSCActivity TscDll = new TSCActivity();
  TscWifiActivity TscEthernetDll = new TscWifiActivity();

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "tsc_blue_print");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if(call.method.equals("ble_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      double widthPaper = call.argument("widthPaper");
      double heightPaper = call.argument("widthPaper");
      String tara = call.argument("tara");
      String peso = call.argument("peso");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("fecha_prod");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");
      int num = call.argument("num");

      TscDll.openport(ipAddress);
      TscDll.setup(45, 110, 6, 3, 0, 3, 3);
      TscDll.clearbuffer();
      TscDll.sendcommand("SIZE " + widthPaper +" mm, " + heightPaper + " mm \n");
      TscDll.sendcommand("SET TEAR ON\n");
      //TscDll.sendcommand("GAP 3 mm, 0 mm\n");
      //TscDll.sendcommand("DIRECTION 1,0 \n");
      //TscDll.sendcommand("REFERENCE 0,0\n");
      //TscDll.sendcommand("OFFSET 0 mm\n");
      //TscDll.sendcommand("SET PEEL OFF\n");
      //TscDll.sendcommand("SET CUTTER OFF\n");
      //TscDll.sendcommand("SET PARTIAL_CUTTER OFF\n");

      if (num < 10) {
        TscDll.sendcommand("@1 = \"1\"\n");
      } else if (num < 100) {
        TscDll.sendcommand("@01 = \"1\"\n");
      }else {
        TscDll.sendcommand("@001 = \"1\"\n");
      }


      TscDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: "+ tara +"\"\n");
      TscDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: "+ bruto +"\"\n");
      TscDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"" + productCode + "\"\n");
      TscDll.barcode(354, 140, "39", 32, 0, 180, 1, 3, ""+ productCode +"");
      TscDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: "+ fecha_prod +"\"\n");
      TscDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. "+ peso +"\"\n");
      TscDll.sendcommand("TEXT 45,184,\"0\",180,9,9,\"24922\"\n");
      TscDll.sendcommand("TEXT 354,184,\"0\",180,7,7, \"PEC. SAN FRANCISCO(MAIZALES)\"\n");

      TscDll.printlabel(1, 1);
      TscDll.closeport(5000);

    } else if (call.method.equals("wifi_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      double widthPaper = call.argument("widthPaper");
      double heightPaper = call.argument("widthPaper");
      String tara = call.argument("tara");
      String peso = call.argument("peso");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("fecha_prod");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");
      int num = call.argument("num");

      TscEthernetDll.openport(ipAddress,9100);
      TscEthernetDll.setup(70, 110, 4, 4, 0, 0, 0);
      TscEthernetDll.clearbuffer();
      TscEthernetDll.sendcommand("SIZE " + widthPaper +" mm, " + heightPaper + " mm\n");
      TscEthernetDll.sendcommand("GAP 3 mm, 0 mm\n");
      TscEthernetDll.sendcommand("DIRECTION 0,0\n");
      TscEthernetDll.sendcommand("REFERENCE 0,0\n");
      TscEthernetDll.sendcommand("OFFSET 0 mm\n");
      TscEthernetDll.sendcommand("SET PEEL OFF\n");
      TscEthernetDll.sendcommand("SET CUTTER OFF\n");
      TscEthernetDll.sendcommand("SET CUTTER OFF\n");
      TscEthernetDll.sendcommand("SET PARTIAL_CUTTER OFF\n");

      if (num < 10) {
        TscEthernetDll.sendcommand("@1 = \"1\"\n");
      } else if (num < 100) {
        TscEthernetDll.sendcommand("@01 = \"1\"\n");
      }else {
        TscEthernetDll.sendcommand("@001 = \"1\"\n");
      }

      TscEthernetDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: "+ tara +"\"\n");
      TscEthernetDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"" + productCode+ "\"\n");
      TscEthernetDll.barcode(354, 140, "39", 32, 0, 180, 1, 3, ""+ productCode +"");
      TscEthernetDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: "+ bruto+"\"\n");
      TscEthernetDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: "+ fecha_prod +"\"\n");
      TscEthernetDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. "+ peso +"\"\n");
      TscEthernetDll.sendcommand("TEXT 54,184,\"0\",180,9,9,\"24922\"\n");
      TscEthernetDll.sendcommand("TEXT 354,181,\"0\",180,7,7,\""+ vendor +"\n");
      TscEthernetDll.printlabel(1, 1);
      TscEthernetDll.closeport(5000);

    } else {
      result.notImplemented();
    }

  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
